/*
 * LircEmu  -  Remote controller emulation for LIRC
 *
 * Copyright 2002 David Kutalek
 *
 *
 * This file is part of LircEmu.
 * 
 * LircEmu is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * LircEmu is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LircEmu; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "../utils.h"

void on_okbtn_clicked( GtkWidget *widget, gpointer data) {
	gtk_widget_destroy(widget);
}

void show_message(char *msg) {
	GtkStatusbar *sb = GTK_STATUSBAR(lookup_widget(mainwindow,"statusbar"));
	guint id;
	
	id = gtk_statusbar_get_context_id(sb,msg);
	gtk_statusbar_push(sb,id,msg);
}
void
on_quit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkToggleButton *toggle = (GtkToggleButton *) lookup_widget(mainwindow,"btnActive");
	
	/* close socket if opened */
	if (gtk_toggle_button_get_active(toggle) == TRUE) {
		close_all();
		unlink_socket();
	}
	
	gtk_exit(0);
}


void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_btnActive_toggled                   (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
	GtkWidget *cmbSocket = lookup_widget(mainwindow,"cmbSocket");
	GtkWidget *frmRemote = lookup_widget(mainwindow,"frmRemote");
	GtkWidget *buttons = lookup_widget(mainwindow,"menuitem6");
	GtkWidget *menu = lookup_widget(mainwindow,"menuitem2");
	GtkStatusbar *sb = GTK_STATUSBAR(lookup_widget(mainwindow,"statusbar"));
	gboolean active = gtk_toggle_button_get_active(togglebutton);
	static guint id = 0;
	char str_activated[256];
	char str_deactivated[] = "Emulation deactivated!";
	char *sfn;

	if (active==TRUE) {
		/* get socket name from cmbSocket */
		sfn = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cmbSocket)->entry));
	
		/* activate socket (using utils.h) */
		if (init_socket(sfn) == -1) {
			gtk_toggle_button_set_active(togglebutton, FALSE);
			show_message("Cannot initialize socket!");
		}
		
		else {		
			/* change gui */
			gtk_widget_set_sensitive(cmbSocket,FALSE);
			gtk_widget_set_sensitive(frmRemote,TRUE);
			gtk_widget_set_sensitive(buttons,TRUE);
			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu), TRUE);
			if (id) gtk_statusbar_pop(sb, id);
			snprintf(str_activated,256,"Activated on %s",sfn);
			id = gtk_statusbar_get_context_id(sb,str_activated);
			gtk_statusbar_push(sb,id,str_activated);
		}
	}
	else {
		/* change gui */
		gtk_widget_set_sensitive(cmbSocket,TRUE);
		gtk_widget_set_sensitive(frmRemote,FALSE);
		gtk_widget_set_sensitive(buttons,FALSE);
		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu), FALSE);
		if (id) gtk_statusbar_pop(sb, id);
		id = gtk_statusbar_get_context_id(sb,str_deactivated);
		gtk_statusbar_push(sb,id,str_deactivated);
		
		/* deactivate socket (using utils.h) */
		if (close_all() == -1) {
			show_message("Error(s) when closing socket");
		}
		
		if (unlink_socket() == -1) {
			show_message("Cannot remove socket");
		}
	}

}


/* FIXME: add tests for return value of send_to_all() */

void
on_remote_btn_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
	gchar *n = gtk_widget_get_name( (GtkWidget *) button);
	gchar *name = NULL;
	char line[256];

	if (strncmp(n,"mi",2) == 0) {
		name = n+2;
	}
	else if (strncmp(n,"btn",3) == 0) {
		name = n+3;
	}
	
	if (strcmp(name,"Quit") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 1, PRESS_LENGTH, "QUIT", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	if (strcmp(name,"Visible") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 2, PRESS_LENGTH, "VISIBLE", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Main") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 3, PRESS_LENGTH, "MAIN", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Back") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 4, PRESS_LENGTH, "BACK", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Prev") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 5, PRESS_LENGTH, "PREV", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Next") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 6, PRESS_LENGTH, "NEXT", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Select") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 7, PRESS_LENGTH, "SELECT", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Tv") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 8, PRESS_LENGTH, "TV", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Video") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 9, PRESS_LENGTH, "VIDEO", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"Music") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 10, PRESS_LENGTH, "MUSIC", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"A") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 11, PRESS_LENGTH, "A", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"B") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 12, PRESS_LENGTH, "B", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"C") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 13, PRESS_LENGTH, "C", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"0") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 14, PRESS_LENGTH, "0", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"1") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 15, PRESS_LENGTH, "1", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"2") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 16, PRESS_LENGTH, "2", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"3") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 17, PRESS_LENGTH, "3", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"4") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 18, PRESS_LENGTH, "4", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"5") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 19, PRESS_LENGTH, "5", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"6") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 20, PRESS_LENGTH, "6", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"7") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 21, PRESS_LENGTH, "7", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"8") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 22, PRESS_LENGTH, "8", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
	
	else if (strcmp(name,"9") == 0) {
		snprintf(line,256,"%016d %d %s %s\n", 23, PRESS_LENGTH, "9", REMOTE_NAME);
		printf(line);
		send_to_all(line);
	}
}


void
on_menuitem2_toggled                   (GtkCheckMenuItem *checkmenuitem,
                                        gpointer         user_data)
{
	GtkToggleButton *btnActive = (GtkToggleButton *) lookup_widget(mainwindow,"btnActive");
	
	gtk_toggle_button_set_active(btnActive, checkmenuitem->active);
}


gboolean
on_mainwin_destroy_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{

  return FALSE;
}


void
on_mi_btn_clicked                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	on_remote_btn_clicked((GtkButton *)menuitem,NULL);
}

